// Copyright (C) 2023  Aravinth Manivannan <realaravinth@batsense.net>
// SPDX-FileCopyrightText: 2023 Aravinth Manivannan <realaravinth@batsense.net>
//
// SPDX-License-Identifier: MIT

//! # Welcome to F3 Documentation!
//!
//! Please refer to the [main documentation](https://f3.forgefriends.org/) for a complete overview.
//! This is an incomplete Rust port of the F3 library created by the ForgeFriends project.
use serde::{Deserialize, Serialize};

pub mod comment;
pub mod identities;
pub mod issue;
pub mod label;
pub mod milestone;
pub mod project;
pub mod pullrequest;
pub mod reaction;
pub mod release;
pub mod repository;
pub mod review;
pub mod topic;
pub mod user;

pub use comment::Comment;
pub use identities::Identities;
pub use issue::Issue;
pub use label::Label;
pub use milestone::Milestone;
pub use project::Project;
pub use pullrequest::PullRequest;
pub use reaction::Reaction;
pub use release::{Release, ReleaseAsset};
pub use repository::Repository;
pub use review::{Review, ReviewComment, ReviewState};
pub use topic::Topic;
pub use user::User;

#[derive(Clone, Debug, Serialize, Deserialize, Eq, PartialEq)]
#[serde(rename_all = "lowercase")]
/// states of issue, milestone, etc with only "open" and "closed" states and "closed" states and
/// "closed" states and "closed" states
pub enum OpenCloseState {
    /// A 'closed' issue will not see any activity in the future
    Closed,
    /// An 'open' issue will see activity in the future
    Open,
}

impl Default for OpenCloseState {
    fn default() -> Self {
        Self::Open
    }
}
